"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dependency_injection_1 = require("@typemon/dependency-injection");
const check_1 = require("@typemon/check");
//
const metadata_key_1 = require("./metadata-key");
//
//
//
function Handler(options = {}) {
    return (target, propertyKey) => {
        if (check_1.Check.isSymbol(propertyKey)) {
            throw new Error(`Decorator 'Handler' can not be used for symbol properties.`);
        }
        const constructor = dependency_injection_1.TargetHandle.targetify(target, propertyKey);
        const targetHandle = dependency_injection_1.TargetHandle.create(constructor);
        const metadatas = targetHandle.hasMetadata(metadata_key_1.MetadataKey.HandlerMetadatas)
            ? targetHandle.getMetadata(metadata_key_1.MetadataKey.HandlerMetadatas)
            : new Map();
        if (metadatas.has(propertyKey)) {
            throw new Error(`Decorator 'Handler' can not be duplicated.`);
        }
        if (check_1.Check.isNotUndefined(options.name)) {
            for (const metadata of metadatas.values()) {
                if (check_1.Check.isNotUndefined(metadata.options.name) && metadata.options.name === options.name) {
                    throw new Error(`Name '${options.name}' already exists.`);
                }
            }
        }
        const metadata = {
            propertyKey,
            options
        };
        metadatas.set(propertyKey, metadata);
        targetHandle.setMetadata(metadata_key_1.MetadataKey.HandlerMetadatas, metadatas);
    };
}
exports.Handler = Handler;
