"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dependency_injection_1 = require("@typemon/dependency-injection");
//
const util_1 = require("./util");
const metadata_key_1 = require("./metadata-key");
const runner_1 = require("./runner");
//
//
//
let globalOptions = {};
function lambdify(target) {
    const targetHandle = dependency_injection_1.TargetHandle.create(target);
    if (targetHandle.hasNotMetadata(metadata_key_1.MetadataKey.ControllerMetadata)) {
        throw new Error(`Decorator 'Controller' is required.`);
    }
    if (targetHandle.hasNotMetadata(metadata_key_1.MetadataKey.HandlerMetadatas)) {
        throw new Error(`There are no handlers in the controller.`);
    }
    const lambdas = {};
    const handlerMetadatas = targetHandle.getMetadata(metadata_key_1.MetadataKey.HandlerMetadatas);
    for (const handlerMetadata of handlerMetadatas.values()) {
        const propertyKey = handlerMetadata.propertyKey;
        const name = handlerMetadata.options.name || util_1.KebabCase.convert(propertyKey);
        const runner = new runner_1.Runner(target, propertyKey, globalOptions);
        const lambda = (event, context) => runner.run(event, context);
        lambdas[name] = lambda;
    }
    return lambdas;
}
exports.lambdify = lambdify;
(function (lambdify) {
    function globally(options) {
        globalOptions = options;
    }
    lambdify.globally = globally;
})(lambdify = exports.lambdify || (exports.lambdify = {}));
