"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const check_1 = require("@typemon/check");
//
//
//
class HttpHeaders {
    constructor(headers = {}) {
        this.map = new Map();
        for (const [name, value] of Object.entries(headers)) {
            this.set(name, value);
        }
    }
    getKey(name) {
        name = name.toLowerCase();
        for (const key of this.map.keys()) {
            if (name === key.toLowerCase()) {
                return key;
            }
        }
        return null;
    }
    [Symbol.iterator]() {
        return this.map[Symbol.iterator]();
    }
    has(name) {
        const key = this.getKey(name);
        const has = check_1.Check.isNotNull(key);
        return has;
    }
    hasNot(name) {
        const has = this.has(name);
        const hasNot = check_1.Check.isFalse(has);
        return hasNot;
    }
    get(name) {
        const key = this.getKey(name);
        if (check_1.Check.isNull(key)) {
            throw new Error(`Name '${name}' does not exist.`);
        }
        const value = this.map.get(key);
        return value;
    }
    set(name, value) {
        if (check_1.Check.isZero(value.length)) {
            throw new Error('The value must not be an empty string or an empty array.');
        }
        if (check_1.Check.isArray(value)) {
            value = value.join(', ');
        }
        const key = this.getKey(name) || name;
        this.map.set(key, value);
    }
    append(name, value) {
        const key = this.getKey(name);
        if (check_1.Check.isZero(value.length)) {
            throw new Error('The value must not be an empty string or an empty array.');
        }
        if (check_1.Check.isNull(key)) {
            this.set(name, value);
        }
        else {
            if (check_1.Check.isArray(value)) {
                value = value.join(', ');
            }
            const previousValue = this.map.get(key);
            const values = [previousValue, value];
            const joinedValues = values.join(', ');
            this.map.set(key, joinedValues);
        }
    }
    delete(name) {
        const key = this.getKey(name);
        if (check_1.Check.isNull(key)) {
            return;
        }
        this.map.delete(key);
    }
    deleteAll(names = this.map.keys()) {
        for (const name of names) {
            this.delete(name);
        }
    }
}
exports.HttpHeaders = HttpHeaders;
