"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
//
const metadata_key_1 = require("./metadata-key");
const parameter_token_1 = require("./parameter-token");
const http_1 = require("./http");
//
//
//
var ParameterResolver;
(function (ParameterResolver) {
    function resolve(metadata, container) {
        return __awaiter(this, void 0, void 0, function* () {
            const identifier = metadata.identifier || metadata.type;
            switch (identifier) {
                case parameter_token_1.ParameterToken.HEADERS: {
                    const request = yield container.get(http_1.HttpRequest);
                    const headers = request.headers;
                    return headers;
                }
                case parameter_token_1.ParameterToken.HEADER: {
                    const name = metadata.get(metadata_key_1.MetadataKey.HeaderName);
                    const request = yield container.get(http_1.HttpRequest);
                    const headers = request.headers;
                    const header = headers.has(name)
                        ? headers.get(name)
                        : null;
                    return header;
                }
                case parameter_token_1.ParameterToken.PATH_PARAMETERS: {
                    const request = yield container.get(http_1.HttpRequest);
                    const parameters = request.pathParameters;
                    return parameters;
                }
                case parameter_token_1.ParameterToken.PATH_PARAMETER: {
                    const key = metadata.get(metadata_key_1.MetadataKey.ParameterKey);
                    const request = yield container.get(http_1.HttpRequest);
                    const parameters = request.pathParameters;
                    const parameter = parameters.has(key)
                        ? parameters.get(key)
                        : null;
                    return parameter;
                }
                case parameter_token_1.ParameterToken.QUERY_PARAMETERS: {
                    const request = yield container.get(http_1.HttpRequest);
                    const parameters = request.queryStringParameters;
                    return parameters;
                }
                case parameter_token_1.ParameterToken.QUERY_PARAMETER: {
                    const key = metadata.get(metadata_key_1.MetadataKey.ParameterKey);
                    const request = yield container.get(http_1.HttpRequest);
                    const parameters = request.queryStringParameters;
                    const parameter = parameters.has(key)
                        ? parameters.get(key)
                        : null;
                    return parameter;
                }
                case parameter_token_1.ParameterToken.BODY: {
                    const request = yield container.get(http_1.HttpRequest);
                    const body = request.body;
                    return body;
                }
                case parameter_token_1.ParameterToken.RESPONSE_HEADERS: {
                    const response = yield container.get(http_1.HttpResponse);
                    const headers = response.headers;
                    return headers;
                }
                case http_1.HttpSharedContext: {
                    const sharedContext = yield container.get(http_1.HttpSharedContext);
                    if (metadata.hasNot(metadata_key_1.MetadataKey.SharedContextKey)) {
                        return sharedContext;
                    }
                    const key = metadata.get(metadata_key_1.MetadataKey.SharedContextKey);
                    const value = sharedContext.get(key);
                    return value;
                }
                default:
                    return container.get(identifier, metadata.flag);
            }
        });
    }
    ParameterResolver.resolve = resolve;
    function resolveAll(metadatas, container) {
        return __awaiter(this, void 0, void 0, function* () {
            const values = [];
            for (const metadata of metadatas) {
                const value = yield resolve(metadata, container);
                values.push(value);
            }
            return values;
        });
    }
    ParameterResolver.resolveAll = resolveAll;
})(ParameterResolver = exports.ParameterResolver || (exports.ParameterResolver = {}));
